pub struct AnalyzeDataDescriptionFeatures {
pub categorical: Option<AnalyzeDataDescriptionFeaturesCategorical>,
pub index: Option<i64>,
pub numeric: Option<AnalyzeDataDescriptionFeaturesNumeric>,
pub text: Option<AnalyzeDataDescriptionFeaturesText>,
}Expand description
Description of the input features in the data set.
This type is not used in any activity, and only used as part of another schema.
Fields
categorical: Option<AnalyzeDataDescriptionFeaturesCategorical>Description of the categorical values of this feature.
index: Option<i64>The feature index.
numeric: Option<AnalyzeDataDescriptionFeaturesNumeric>Description of the numeric values of this feature.
text: Option<AnalyzeDataDescriptionFeaturesText>Description of multiple-word text values of this feature.